```
Usage: vcd network routed remove-metadata [OPTIONS] <name>

Options:
  -k, --key <key>        metadata key name  [required]
  -d, --domain <domain>  metadata domain
  -h, --help             Show this message and exit.

```
